Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::view::indirect_fn Member List

This is the complete list of members for ranges::v3::view::indirect_fn, including all inherited members.

Constraint typedef (defined in ranges::v3::view::indirect_fn) | ranges::v3::view::indirect_fn |
indirect (defined in ranges::v3::view::indirect_fn) | ranges::v3::view::indirect_fn | related
operator()(Rng &&rng) const noexcept(noexcept(decltype(indirect_view< all_t< Rng >>{all(static_cast< Rng &&>(rng))})(indirect_view< all_t< Rng >>{all(static_cast< Rng &&>(rng))}))) -> decltype(indirect_view< all_t< Rng >> (defined in ranges::v3::view::indirect_fn) | ranges::v3::view::indirect_fn |